@@ -88,6 +88,26 @@ class TestVenvConfig:
             'dep1==1.5', 'dep2==2.1', 'dep3==3.0', 'dep4==4.0',
         ]
 
+    def test_force_dep_with_url(self, initproj):
+        initproj("example123-0.5", filedefs={
+            'tox.ini': '''
+            [tox]
+
+            [testenv]
+            deps=
+                dep1==1.0
+                https://pypi.python.org/xyz/pkg1.tar.gz
+            '''
+        })
+        config = parseconfig(
+            ['--force-dep=dep1==1.5'])
+        assert config.option.force_dep == [
+            'dep1==1.5'
+        ]
+        assert [str(x) for x in config.envconfigs['python'].deps] == [
+            'dep1==1.5', 'https://pypi.python.org/xyz/pkg1.tar.gz'
+        ]
+
     def test_is_same_dep(self):
         """
         Ensure correct parseini._is_same_dep is working with a few samples.
@@ -254,6 +274,28 @@ class TestIniParserAgainstCommandsKey:
             ["echo", "cmd", "1", "2", "3", "4", "cmd", "2"],
         ]
 
+    def test_command_env_substitution(self, newconfig):
+        """Ensure referenced {env:key:default} values are substituted correctly."""
+        config = newconfig("""
+           [testenv:py27]
+           setenv =
+             TEST=testvalue
+           commands =
+             ls {env:TEST}
+        """)
+        reader = SectionReader("testenv:py27", config._cfg)
+        x = reader.getargvlist("commands")
+        assert x == [
+            "ls testvalue".split()
+        ]
+        assert x != [
+            "ls {env:TEST}".split()
+        ]
+        y = reader.getargvlist("setenv")
+        assert y == [
+            "TEST=testvalue".split()
+        ]
+
 
 class TestIniParser:
     def test_getstring_single(self, tmpdir, newconfig):
@@ -598,6 +640,7 @@ class TestConfigTestEnv:
         int_hashseed = int(hashseed)
         # hashseed is random by default, so we can't assert a specific value.
         assert int_hashseed > 0
+        assert envconfig.ignore_outcome is False
 
     def test_sitepackages_switch(self, tmpdir, newconfig):
         config = newconfig(["--sitepackages"], "")
@@ -695,6 +738,32 @@ class TestConfigTestEnv:
         assert envconfig.setenv['PYTHONPATH'] == 'something'
         assert envconfig.setenv['ANOTHER_VAL'] == 'else'
 
+    def test_setenv_with_envdir_and_basepython(self, tmpdir, newconfig):
+        config = newconfig("""
+            [testenv]
+            setenv =
+                VAL = {envdir}
+            basepython = {env:VAL}
+        """)
+        assert len(config.envconfigs) == 1
+        envconfig = config.envconfigs['python']
+        assert 'VAL' in envconfig.setenv
+        assert envconfig.setenv['VAL'] == envconfig.envdir
+        assert envconfig.basepython == envconfig.envdir
+
+    def test_setenv_ordering_1(self, tmpdir, newconfig):
+        config = newconfig("""
+            [testenv]
+            setenv=
+                VAL={envdir}
+            commands=echo {env:VAL}
+        """)
+        assert len(config.envconfigs) == 1
+        envconfig = config.envconfigs['python']
+        assert 'VAL' in envconfig.setenv
+        assert envconfig.setenv['VAL'] == envconfig.envdir
+        assert str(envconfig.envdir) in envconfig.commands[0]
+
     @pytest.mark.parametrize("plat", ["win32", "linux2"])
     def test_passenv_as_multiline_list(self, tmpdir, newconfig, monkeypatch, plat):
         monkeypatch.setattr(sys, "platform", plat)
@@ -721,6 +790,7 @@ class TestConfigTestEnv:
         assert "PATH" in envconfig.passenv
         assert "PIP_INDEX_URL" in envconfig.passenv
         assert "LANG" in envconfig.passenv
+        assert "LD_LIBRARY_PATH" in envconfig.passenv
         assert "A123A" in envconfig.passenv
         assert "A123B" in envconfig.passenv
 
@@ -926,6 +996,18 @@ class TestConfigTestEnv:
         assert argv[7][0] == config.homedir.join(".tox", "distshare")
         assert argv[8][0] == conf.envlogdir
 
+    def test_substitution_notfound_issue246(tmpdir, newconfig):
+        config = newconfig("""
+            [testenv:py27]
+            setenv =
+                FOO={envbindir}
+                BAR={envsitepackagesdir}
+        """)
+        conf = config.envconfigs['py27']
+        env = conf.setenv
+        assert 'FOO' in env
+        assert 'BAR' in env
+
     def test_substitution_positional(self, newconfig):
         inisource = """
             [testenv:py27]
@@ -1214,6 +1296,14 @@ class TestConfigTestEnv:
         assert [d.name for d in configs["py27-django1.6"].deps] \
             == ["Django==1.6"]
 
+    def test_ignore_outcome(self, newconfig):
+        inisource = """
+            [testenv]
+            ignore_outcome=True
+        """
+        config = newconfig([], inisource).envconfigs
+        assert config["python"].ignore_outcome is True
+
 
 class TestGlobalOptions:
     def test_notest(self, newconfig):
