@@ -7,6 +7,7 @@ import tox.config
 from tox.venv import *  # noqa
 from tox.interpreters import NoInterpreterInfo
 
+
 # def test_global_virtualenv(capfd):
 #    v = VirtualEnv()
 #    l = v.list()
@@ -611,3 +612,17 @@ def test_command_relative_issue26(newmocksession, tmpdir, monkeypatch):
     x4 = venv.getcommandpath("x", cwd=tmpdir)
     assert x4.endswith(os.sep + 'x')
     mocksession.report.expect("warning", "*test command found but not*")
+
+
+def test_ignore_outcome_failing_cmd(newmocksession):
+    mocksession = newmocksession([], """
+        [testenv]
+        commands=testenv_fail
+        ignore_outcome=True
+    """)
+
+    venv = mocksession.getenv('python')
+    venv.test()
+    assert venv.status == "ignored failed command"
+    mocksession.report.expect("warning", "*command failed but result from "
+                                         "testenv is ignored*")
